==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/BuildConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.BuildConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Configuration of the build.
 * @property baseOs Base OS used to build and run the app.
 * @property environmentVariables List of environment variables to be passed to the build.
 * @property platform Platform to be used to build and run the app.
 * @property platformVersion Platform version to be used to build and run the app.
 * @property preBuildSteps List of steps to perform before the build.
 */
public data class BuildConfigurationArgs(
    public val baseOs: Output<String>? = null,
    public val environmentVariables: Output<List<EnvironmentVariableArgs>>? = null,
    public val platform: Output<String>? = null,
    public val platformVersion: Output<String>? = null,
    public val preBuildSteps: Output<List<PreBuildStepArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.BuildConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.BuildConfigurationArgs =
        com.pulumi.azurenative.app.inputs.BuildConfigurationArgs.builder()
            .baseOs(baseOs?.applyValue({ args0 -> args0 }))
            .environmentVariables(
                environmentVariables?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .platform(platform?.applyValue({ args0 -> args0 }))
            .platformVersion(platformVersion?.applyValue({ args0 -> args0 }))
            .preBuildSteps(
                preBuildSteps?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [BuildConfigurationArgs].
 */
@PulumiTagMarker
public class BuildConfigurationArgsBuilder internal constructor() {
    private var baseOs: Output<String>? = null

    private var environmentVariables: Output<List<EnvironmentVariableArgs>>? = null

    private var platform: Output<String>? = null

    private var platformVersion: Output<String>? = null

    private var preBuildSteps: Output<List<PreBuildStepArgs>>? = null

    /**
     * @param value Base OS used to build and run the app.
     */
    @JvmName("mvglgovaxbarkcaw")
    public suspend fun baseOs(`value`: Output<String>) {
        this.baseOs = value
    }

    /**
     * @param value List of environment variables to be passed to the build.
     */
    @JvmName("twyepvuvwrlpodsi")
    public suspend fun environmentVariables(`value`: Output<List<EnvironmentVariableArgs>>) {
        this.environmentVariables = value
    }

    @JvmName("dmssyuxtpsnbewjc")
    public suspend fun environmentVariables(vararg values: Output<EnvironmentVariableArgs>) {
        this.environmentVariables = Output.all(values.asList())
    }

    /**
     * @param values List of environment variables to be passed to the build.
     */
    @JvmName("latboyyfdwlcvrbg")
    public suspend fun environmentVariables(values: List<Output<EnvironmentVariableArgs>>) {
        this.environmentVariables = Output.all(values)
    }

    /**
     * @param value Platform to be used to build and run the app.
     */
    @JvmName("raetpwomuqdpyddj")
    public suspend fun platform(`value`: Output<String>) {
        this.platform = value
    }

    /**
     * @param value Platform version to be used to build and run the app.
     */
    @JvmName("olvayaeisjsyyxrq")
    public suspend fun platformVersion(`value`: Output<String>) {
        this.platformVersion = value
    }

    /**
     * @param value List of steps to perform before the build.
     */
    @JvmName("rawbvbewbwkgoebe")
    public suspend fun preBuildSteps(`value`: Output<List<PreBuildStepArgs>>) {
        this.preBuildSteps = value
    }

    @JvmName("yjxvkgpmsbsvwrbt")
    public suspend fun preBuildSteps(vararg values: Output<PreBuildStepArgs>) {
        this.preBuildSteps = Output.all(values.asList())
    }

    /**
     * @param values List of steps to perform before the build.
     */
    @JvmName("mcwneexelhehpxje")
    public suspend fun preBuildSteps(values: List<Output<PreBuildStepArgs>>) {
        this.preBuildSteps = Output.all(values)
    }

    /**
     * @param value Base OS used to build and run the app.
     */
    @JvmName("dbibteslcfbfmjto")
    public suspend fun baseOs(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baseOs = mapped
    }

    /**
     * @param value List of environment variables to be passed to the build.
     */
    @JvmName("gdrevxdlltyvwhfy")
    public suspend fun environmentVariables(`value`: List<EnvironmentVariableArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.environmentVariables = mapped
    }

    /**
     * @param argument List of environment variables to be passed to the build.
     */
    @JvmName("wteoxhonijgwwrpu")
    public suspend
    fun environmentVariables(argument: List<suspend EnvironmentVariableArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EnvironmentVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param argument List of environment variables to be passed to the build.
     */
    @JvmName("nrdwoxqjmlsndybh")
    public suspend fun environmentVariables(
        vararg
        argument: suspend EnvironmentVariableArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EnvironmentVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param argument List of environment variables to be passed to the build.
     */
    @JvmName("olocggvvfmmxffll")
    public suspend
    fun environmentVariables(argument: suspend EnvironmentVariableArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EnvironmentVariableArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param values List of environment variables to be passed to the build.
     */
    @JvmName("aabkkernwdeiqaya")
    public suspend fun environmentVariables(vararg values: EnvironmentVariableArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.environmentVariables = mapped
    }

    /**
     * @param value Platform to be used to build and run the app.
     */
    @JvmName("ydssnjktlewxnhlh")
    public suspend fun platform(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.platform = mapped
    }

    /**
     * @param value Platform version to be used to build and run the app.
     */
    @JvmName("eferlkwkbryhbalk")
    public suspend fun platformVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.platformVersion = mapped
    }

    /**
     * @param value List of steps to perform before the build.
     */
    @JvmName("hsmebehrtnbfugvk")
    public suspend fun preBuildSteps(`value`: List<PreBuildStepArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.preBuildSteps = mapped
    }

    /**
     * @param argument List of steps to perform before the build.
     */
    @JvmName("jouijxecjgcjvebp")
    public suspend fun preBuildSteps(argument: List<suspend PreBuildStepArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PreBuildStepArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.preBuildSteps = mapped
    }

    /**
     * @param argument List of steps to perform before the build.
     */
    @JvmName("mjguxpcxtxycoual")
    public suspend fun preBuildSteps(vararg argument: suspend PreBuildStepArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            PreBuildStepArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.preBuildSteps = mapped
    }

    /**
     * @param argument List of steps to perform before the build.
     */
    @JvmName("uhwjqyloqfyjhsqh")
    public suspend fun preBuildSteps(argument: suspend PreBuildStepArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PreBuildStepArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.preBuildSteps = mapped
    }

    /**
     * @param values List of steps to perform before the build.
     */
    @JvmName("hqkjjyfbxwqnqspi")
    public suspend fun preBuildSteps(vararg values: PreBuildStepArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preBuildSteps = mapped
    }

    internal fun build(): BuildConfigurationArgs = BuildConfigurationArgs(
        baseOs = baseOs,
        environmentVariables = environmentVariables,
        platform = platform,
        platformVersion = platformVersion,
        preBuildSteps = preBuildSteps,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/BuildConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.BuildConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Configuration of the build.
 * @property baseOs Base OS used to build and run the app.
 * @property environmentVariables List of environment variables to be passed to the build.
 * @property platform Platform to be used to build and run the app.
 * @property platformVersion Platform version to be used to build and run the app.
 * @property preBuildSteps List of steps to perform before the build.
 */
public data class BuildConfigurationArgs(
    public val baseOs: Output<String>? = null,
    public val environmentVariables: Output<List<EnvironmentVariableArgs>>? = null,
    public val platform: Output<String>? = null,
    public val platformVersion: Output<String>? = null,
    public val preBuildSteps: Output<List<PreBuildStepArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.BuildConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.BuildConfigurationArgs =
        com.pulumi.azurenative.app.inputs.BuildConfigurationArgs.builder()
            .baseOs(baseOs?.applyValue({ args0 -> args0 }))
            .environmentVariables(
                environmentVariables?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .platform(platform?.applyValue({ args0 -> args0 }))
            .platformVersion(platformVersion?.applyValue({ args0 -> args0 }))
            .preBuildSteps(
                preBuildSteps?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [BuildConfigurationArgs].
 */
@PulumiTagMarker
public class BuildConfigurationArgsBuilder internal constructor() {
    private var baseOs: Output<String>? = null

    private var environmentVariables: Output<List<EnvironmentVariableArgs>>? = null

    private var platform: Output<String>? = null

    private var platformVersion: Output<String>? = null

    private var preBuildSteps: Output<List<PreBuildStepArgs>>? = null

    /**
     * @param value Base OS used to build and run the app.
     */
    @JvmName("eflkqeqfjfguxert")
    public suspend fun baseOs(`value`: Output<String>) {
        this.baseOs = value
    }

    /**
     * @param value List of environment variables to be passed to the build.
     */
    @JvmName("fkduqbcvdcvciycy")
    public suspend fun environmentVariables(`value`: Output<List<EnvironmentVariableArgs>>) {
        this.environmentVariables = value
    }

    @JvmName("gpqgveyndwvffxlq")
    public suspend fun environmentVariables(vararg values: Output<EnvironmentVariableArgs>) {
        this.environmentVariables = Output.all(values.asList())
    }

    /**
     * @param values List of environment variables to be passed to the build.
     */
    @JvmName("gwpocvyaujcnuqma")
    public suspend fun environmentVariables(values: List<Output<EnvironmentVariableArgs>>) {
        this.environmentVariables = Output.all(values)
    }

    /**
     * @param value Platform to be used to build and run the app.
     */
    @JvmName("fiquqtdiwyubkyqo")
    public suspend fun platform(`value`: Output<String>) {
        this.platform = value
    }

    /**
     * @param value Platform version to be used to build and run the app.
     */
    @JvmName("lfoyhbskiochrnln")
    public suspend fun platformVersion(`value`: Output<String>) {
        this.platformVersion = value
    }

    /**
     * @param value List of steps to perform before the build.
     */
    @JvmName("kvdhrxgjfcitkdvx")
    public suspend fun preBuildSteps(`value`: Output<List<PreBuildStepArgs>>) {
        this.preBuildSteps = value
    }

    @JvmName("cvwhqvtxainpofud")
    public suspend fun preBuildSteps(vararg values: Output<PreBuildStepArgs>) {
        this.preBuildSteps = Output.all(values.asList())
    }

    /**
     * @param values List of steps to perform before the build.
     */
    @JvmName("tieiyqmifbvxvfpp")
    public suspend fun preBuildSteps(values: List<Output<PreBuildStepArgs>>) {
        this.preBuildSteps = Output.all(values)
    }

    /**
     * @param value Base OS used to build and run the app.
     */
    @JvmName("tilsmnpdalkfyeph")
    public suspend fun baseOs(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baseOs = mapped
    }

    /**
     * @param value List of environment variables to be passed to the build.
     */
    @JvmName("xfnoeoomrmycohvt")
    public suspend fun environmentVariables(`value`: List<EnvironmentVariableArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.environmentVariables = mapped
    }

    /**
     * @param argument List of environment variables to be passed to the build.
     */
    @JvmName("uhlxxphdlgakgeou")
    public suspend
    fun environmentVariables(argument: List<suspend EnvironmentVariableArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EnvironmentVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param argument List of environment variables to be passed to the build.
     */
    @JvmName("cyqknsjoslsttgxp")
    public suspend fun environmentVariables(
        vararg
        argument: suspend EnvironmentVariableArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EnvironmentVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param argument List of environment variables to be passed to the build.
     */
    @JvmName("odbigcoruhejflyh")
    public suspend
    fun environmentVariables(argument: suspend EnvironmentVariableArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EnvironmentVariableArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.environmentVariables = mapped
    }

    /**
     * @param values List of environment variables to be passed to the build.
     */
    @JvmName("smmwnmpdvhmbukse")
    public suspend fun environmentVariables(vararg values: EnvironmentVariableArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.environmentVariables = mapped
    }

    /**
     * @param value Platform to be used to build and run the app.
     */
    @JvmName("fcsysldhwedygdup")
    public suspend fun platform(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.platform = mapped
    }

    /**
     * @param value Platform version to be used to build and run the app.
     */
    @JvmName("fhjfvhdqmprompbm")
    public suspend fun platformVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.platformVersion = mapped
    }

    /**
     * @param value List of steps to perform before the build.
     */
    @JvmName("lylpexcqhvbgpomc")
    public suspend fun preBuildSteps(`value`: List<PreBuildStepArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.preBuildSteps = mapped
    }

    /**
     * @param argument List of steps to perform before the build.
     */
    @JvmName("aoqprnwbhbjjjpqq")
    public suspend fun preBuildSteps(argument: List<suspend PreBuildStepArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PreBuildStepArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.preBuildSteps = mapped
    }

    /**
     * @param argument List of steps to perform before the build.
     */
    @JvmName("posxpiqfmdbrodrw")
    public suspend fun preBuildSteps(vararg argument: suspend PreBuildStepArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            PreBuildStepArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.preBuildSteps = mapped
    }

    /**
     * @param argument List of steps to perform before the build.
     */
    @JvmName("eiaahsowuyymwqru")
    public suspend fun preBuildSteps(argument: suspend PreBuildStepArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PreBuildStepArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.preBuildSteps = mapped
    }

    /**
     * @param values List of steps to perform before the build.
     */
    @JvmName("rkfeepcbkiaapjcw")
    public suspend fun preBuildSteps(vararg values: PreBuildStepArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preBuildSteps = mapped
    }

    internal fun build(): BuildConfigurationArgs = BuildConfigurationArgs(
        baseOs = baseOs,
        environmentVariables = environmentVariables,
        platform = platform,
        platformVersion = platformVersion,
        preBuildSteps = preBuildSteps,
    )
}
